==> runawfe-free-server-4.3.0.tar.gz: runawfe-free-server-4.3.0/wfe-service/src/main/java/ru/runa/wfe/service/delegate/SubstitutionServiceDelegate.java <==
/*
 * This file is part of the RUNA WFE project.
 * 
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation; version 2.1 
 * of the License. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU Lesser General Public License for more details. 
 * 
 * You should have received a copy of the GNU Lesser General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 */
package ru.runa.wfe.service.delegate;

import java.util.List;

import ru.runa.wfe.service.SubstitutionService;
import ru.runa.wfe.ss.Substitution;
import ru.runa.wfe.ss.SubstitutionCriteria;
import ru.runa.wfe.user.User;

/**
 * Created on 30.01.2006
 * 
 */
public class SubstitutionServiceDelegate extends EJB3Delegate implements SubstitutionService {

    public SubstitutionServiceDelegate() {
        super(SubstitutionService.class);
    }

    private SubstitutionService getSubstitutionService() {
        return getService();
    }

    @Override
    public Substitution createSubstitution(User user, Substitution substitution) {
        try {
            return getSubstitutionService().createSubstitution(user, substitution);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public List<Substitution> getSubstitutions(User user, Long actorId) {
        try {
            return getSubstitutionService().getSubstitutions(user, actorId);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public void deleteSubstitutions(User user, List<Long> substitutionIds) {
        try {
            getSubstitutionService().deleteSubstitutions(user, substitutionIds);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public Substitution getSubstitution(User user, Long substitutionId) {
        try {
            return getSubstitutionService().getSubstitution(user, substitutionId);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public void updateSubstitution(User user, Substitution substitution) {
        try {
            getSubstitutionService().updateSubstitution(user, substitution);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public <T extends SubstitutionCriteria> void createCriteria(User user, T substitutionCriteria) {
        try {
            getSubstitutionService().createCriteria(user, substitutionCriteria);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public SubstitutionCriteria getCriteria(User user, Long criteriaId) {
        try {
            return getSubstitutionService().getCriteria(user, criteriaId);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public SubstitutionCriteria getCriteriaByName(User user, String name) {
        try {
            return getSubstitutionService().getCriteriaByName(user, name);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public List<SubstitutionCriteria> getAllCriterias(User user) {
        try {
            return getSubstitutionService().getAllCriterias(user);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public void updateCriteria(User user, SubstitutionCriteria substitutionCriteria) {
        try {
            getSubstitutionService().updateCriteria(user, substitutionCriteria);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public void deleteCriterias(User user, List<SubstitutionCriteria> criterias) {
        try {
            getSubstitutionService().deleteCriterias(user, criterias);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public void deleteCriteria(User user, SubstitutionCriteria substitutionCriteria) {
        try {
            getSubstitutionService().deleteCriteria(user, substitutionCriteria);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public List<Substitution> getSubstitutionsByCriteria(User user, SubstitutionCriteria substitutionCriteria) {
        try {
            return getSubstitutionService().getSubstitutionsByCriteria(user, substitutionCriteria);
        } catch (Exception e) {
            throw handleException(e);
        }
    }
}

==> runawfe-free-server-4.5.0.tar.gz: runawfe-free-server-4.5.0/wfe-service/src/main/java/ru/runa/wfe/service/delegate/SubstitutionServiceDelegate.java <==
/*
 * This file is part of the RUNA WFE project.
 * 
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation; version 2.1 
 * of the License. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU Lesser General Public License for more details. 
 * 
 * You should have received a copy of the GNU Lesser General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 */
package ru.runa.wfe.service.delegate;

import java.util.List;

import ru.runa.wfe.service.SubstitutionService;
import ru.runa.wfe.ss.Substitution;
import ru.runa.wfe.ss.SubstitutionCriteria;
import ru.runa.wfe.user.User;

/**
 * Created on 30.01.2006
 * 
 */
public class SubstitutionServiceDelegate extends Ejb3Delegate implements SubstitutionService {

    public SubstitutionServiceDelegate() {
        super(SubstitutionService.class);
    }

    private SubstitutionService getSubstitutionService() {
        return getService();
    }

    @Override
    public Substitution createSubstitution(User user, Substitution substitution) {
        try {
            return getSubstitutionService().createSubstitution(user, substitution);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public List<Substitution> getSubstitutions(User user, Long actorId) {
        try {
            return getSubstitutionService().getSubstitutions(user, actorId);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public void deleteSubstitutions(User user, List<Long> substitutionIds) {
        try {
            getSubstitutionService().deleteSubstitutions(user, substitutionIds);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public Substitution getSubstitution(User user, Long substitutionId) {
        try {
            return getSubstitutionService().getSubstitution(user, substitutionId);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public void updateSubstitution(User user, Substitution substitution) {
        try {
            getSubstitutionService().updateSubstitution(user, substitution);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public <T extends SubstitutionCriteria> void createCriteria(User user, T substitutionCriteria) {
        try {
            getSubstitutionService().createCriteria(user, substitutionCriteria);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public SubstitutionCriteria getCriteria(User user, Long criteriaId) {
        try {
            return getSubstitutionService().getCriteria(user, criteriaId);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public SubstitutionCriteria getCriteriaByName(User user, String name) {
        try {
            return getSubstitutionService().getCriteriaByName(user, name);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public List<SubstitutionCriteria> getAllCriterias(User user) {
        try {
            return getSubstitutionService().getAllCriterias(user);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public void updateCriteria(User user, SubstitutionCriteria substitutionCriteria) {
        try {
            getSubstitutionService().updateCriteria(user, substitutionCriteria);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public void deleteCriterias(User user, List<SubstitutionCriteria> criterias) {
        try {
            getSubstitutionService().deleteCriterias(user, criterias);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public void deleteCriteria(User user, SubstitutionCriteria substitutionCriteria) {
        try {
            getSubstitutionService().deleteCriteria(user, substitutionCriteria);
        } catch (Exception e) {
            throw handleException(e);
        }
    }

    @Override
    public List<Substitution> getSubstitutionsByCriteria(User user, SubstitutionCriteria substitutionCriteria) {
        try {
            return getSubstitutionService().getSubstitutionsByCriteria(user, substitutionCriteria);
        } catch (Exception e) {
            throw handleException(e);
        }
    }
}
